==> myfaces-core-assembly-2.0.24-src.zip: org/apache/myfaces/config/element/NavigationCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.element;

import java.io.Serializable;



/**
 * Entry of the Collection returned by {@link NavigationRule#getNavigationCases()}.
 *
 * @author Manfred Geiler (latest modification by $Author: bommel $)
 * @version $Revision: 1187700 $ $Date: 2011-10-22 12:19:37 +0000 (Sat, 22 Oct 2011) $
 */
public abstract class NavigationCase implements Serializable
{
    // <!ELEMENT navigation-case (description*, display-name*, icon*, from-action?, from-outcome?, to-view-id, redirect?)>

    public abstract String getFromAction();
    public abstract String getFromOutcome();
    public abstract String getIf();
    public abstract Redirect getRedirect();
    public abstract String getToViewId();
}

==> myfaces-core-assembly-2.1.18-src.zip: org/apache/myfaces/config/element/NavigationCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.config.element;

import java.io.Serializable;



/**
 * Entry of the Collection returned by {@link NavigationRule#getNavigationCases()}.
 *
 * @author Manfred Geiler (latest modification by $Author: struberg $)
 * @version $Revision: 1188686 $ $Date: 2011-10-25 14:59:52 +0000 (Tue, 25 Oct 2011) $
 */
public abstract class NavigationCase implements Serializable
{
    // <!ELEMENT navigation-case (description*, display-name*, icon*, from-action?,
    // from-outcome?, to-view-id, redirect?)>

    public abstract String getFromAction();
    public abstract String getFromOutcome();
    public abstract String getIf();
    public abstract Redirect getRedirect();
    public abstract String getToViewId();
}
